emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master 04f915d 3/3: ; Tighten up vc-state tests, allowed b


From: Dmitry Gutov
Subject: [Emacs-diffs] master 04f915d 3/3: ; Tighten up vc-state tests, allowed by the previous change
Date: Sun, 30 Apr 2017 21:30:19 -0400 (EDT)

branch: master
commit 04f915db9732d275ad1de8add8009c2af9d94d1f
Author: Dmitry Gutov <address@hidden>
Commit: Dmitry Gutov <address@hidden>

    ; Tighten up vc-state tests, allowed by the previous change
---
 test/lisp/vc/vc-tests.el | 13 ++++++++-----
 1 file changed, 8 insertions(+), 5 deletions(-)

diff --git a/test/lisp/vc/vc-tests.el b/test/lisp/vc/vc-tests.el
index ad4399d..f2898cb 100644
--- a/test/lisp/vc/vc-tests.el
+++ b/test/lisp/vc/vc-tests.el
@@ -329,8 +329,10 @@ This checks also `vc-backend' and 
`vc-responsible-backend'."
            ;; Write a new file.  Check state.
            (write-region "foo" nil tmp-name nil 'nomessage)
 
-            (message "vc-state3 %s" (vc-state tmp-name))
-           (should (null (vc-state tmp-name)))
+            ;; nil: Mtn
+            ;; unregistered: Bzr CVS Git Hg SVN RCS
+            (message "vc-state3 %s %s" backend (vc-state tmp-name backend))
+           (should (memq (vc-state tmp-name backend) '(nil unregistered)))
 
            ;; Register a file.  Check state.
            (vc-register
@@ -348,10 +350,11 @@ This checks also `vc-backend' and 
`vc-responsible-backend'."
                      'vc-test--unregister-function backend tmp-name)
                     'vc-not-supported)
                 (message "vc-state5 unsupported")
               ;; nil: Bzr Git Hg RCS
               ;; unsupported: CVS Mtn SCCS SRC SVN
-              (message "vc-state5 %s" (vc-state tmp-name))
-              (should (null (vc-state tmp-name))))))
+              (message "vc-state5 %s %s" backend (vc-state tmp-name backend))
+              (should (memq (vc-state tmp-name backend)
+                            '(nil unregistered))))))
 
       ;; Save exit.
       (ignore-errors (run-hooks 'vc-test--cleanup-hook)))))
@@ -348,10 +350,11 @@ This checks also `vc-backend' and 
                     'vc-not-supported)
                 (message "vc-state5 unsupported")
-              ;; nil: Bzr Git Hg RCS
+              ;; unregistered: Bzr Git RCS Hg
               ;; unsupported: CVS Mtn SCCS SRC SVN



reply via email to

[Prev in Thread] Current Thread [Next in Thread]